__title__ = 'Flask-DJ'
__description__ = 'Django (mvc) structure for your Flask project.'
__url__ = 'https://github.com/AlexandrovRoman/Flask-DJ'
__version__ = '0.1.6'
__author__ = 'Alexandrov Roman'
__author_email__ = 'flask-dj.feedback@yandex.com'
__license__ = 'MIT License'
__keywords__ = 'mvc django flask structure'
